@@ -17,6 +17,16 @@ try:
 except:
     os.system('pip install clipboard')
     import clipboard
+    
+try:
+    import win32api
+except:
+    os.system('pip install pywin32')
+    import win32api
+    
+import win32con
+import win32gui
+import ctypes
 
 from codingnow.game.platform.player import *
 from codingnow.game.platform.block import *
@@ -26,10 +36,20 @@ from codingnow.game.platform.lava import *
 from codingnow.game.platform.bullet import *
 from codingnow.game.platform.bullet_monster import *
 from codingnow.game.platform.exitdoor import *
+from codingnow.game.platform.teleport import *
 from codingnow.game.platform.weapon import *
 from codingnow.game.platform.hp import *
 
+# RECT 구조체 정의
+class RECT(ctypes.Structure):
+    _fields_ = [("left", ctypes.c_long),
+                ("top", ctypes.c_long),
+                ("right", ctypes.c_long),
+                ("bottom", ctypes.c_long)]
+    
 class PlatformGame():
+    # TRANSPARENT_COLOR = (255, 0, 128) #
+    TRANSPARENT_COLOR = (0, 0, 0) #
     player:Player = None
     on_mouse_point = False
     event_func_p = None
@@ -41,14 +61,22 @@ class PlatformGame():
         'snd' : None,
         }
     
-    def __init__(self,screen:Surface, on_mouse: bool=False) -> None:
-        self.screen = screen
+    def __init__(self,screen:Surface, on_mouse: bool=False, on_alpha: bool=False, color_alpha :tuple=(0,0,0)) -> None:
+        self.on_alpha = on_alpha
+        if self.on_alpha:            
+            self.TRANSPARENT_COLOR = color_alpha
+            self.hwnd = pygame.display.get_wm_info()['window']
+            self.set_background_Alpha(self.hwnd)
+            self.screen = pygame.display.set_mode((screen.get_width(), screen.get_height()), pygame.SRCALPHA| pygame.NOFRAME)
+        else:
+            self.screen = screen
         self.player = None
         self.group_block = pygame.sprite.Group()
         self.group_coin = pygame.sprite.Group()
         self.group_lava = pygame.sprite.Group()
         self.group_monster = pygame.sprite.Group()
         self.group_exitDoor = pygame.sprite.Group()
+        self.group_Teleport = pygame.sprite.Group()
         self.group_weapon = pygame.sprite.Group()
         self.group_bullet = pygame.sprite.Group()
         self.group_bulletMonster = pygame.sprite.Group()
@@ -64,6 +92,17 @@ class PlatformGame():
         self.mfont20 = pygame.font.SysFont('malgungothic', 20)
         self.mfont30 = pygame.font.SysFont('malgungothic', 30)    
         
+            
+    def RGB(self,r, g, b):
+        return r | (g << 8) | (b << 16)
+    
+    def set_background_Alpha(self, hwnd):
+        win32gui.SetWindowLong(hwnd, win32con.GWL_EXSTYLE, win32gui.GetWindowLong(
+                       hwnd, win32con.GWL_EXSTYLE) | win32con.WS_EX_LAYERED)
+
+        # win32gui.SetLayeredWindowAttributes(hwnd, win32api.RGB(255,0,128), 0, win32con.LWA_COLORKEY)
+        win32gui.SetLayeredWindowAttributes(hwnd, self.RGB(*self.TRANSPARENT_COLOR), 0, win32con.LWA_COLORKEY)
+        
     def set_folder(self, images:str=None, sounds:str=None):
         self.path['img'] = images
         self.path['snd'] = sounds
@@ -96,6 +135,7 @@ class PlatformGame():
         self.group_block.empty()
         self.group_lava.empty()
         self.group_exitDoor.empty()
+        self.group_Teleport.empty()
         self.group_weapon.empty()
         self.group_hp.empty()
         try:            
@@ -139,6 +179,12 @@ class PlatformGame():
                         width=values[4]
                         height=values[5]
                         self.group_exitDoor.add(ExitDoor(self.screen,img,x,y,next_level,width,height))
+                    if key == 'teleport':
+                        toX = values[3]
+                        toY = values[4]
+                        width = values[5]
+                        height = values[6]
+                        self.group_Teleport.add(Teleport(self.screen,img,x,y,toX,toY,width,height))
                     if key == 'lava':
                         self.group_lava.add(Lava(self.screen,img,x,y))
                     if key == 'weapon':
@@ -240,7 +286,12 @@ class PlatformGame():
         self.map_data[level]['exit'].append([filename,x,y,next_level,width,height])
         if self.lastExt < level:
             self.lastExt = level
-
+            
+    def add_map_teleport(self,level:int, filename:str, x:int, y:int, toX:int, toY:int, width:int=60, height:int=60):
+        filename = self.get_folder_img(filename)
+        self.check_map_init(level,'teleport')
+        self.map_data[level]['teleport'].append([filename,x,y,toX,toY,width,height])
+            
     def add_bullet(self,filename):
         # print(filename)
         # filename = self.get_folder_img(filename)
@@ -323,6 +374,10 @@ class PlatformGame():
                 self.screen.blit(img, rect)
                 
     def draw_bg_img(self):
+        if self.on_alpha:    
+            self.screen.fill(self.TRANSPARENT_COLOR)
+            return
+        
         img = None
         if self.player is not None:
             if self.player.level in self.bgimgs:
@@ -370,6 +425,7 @@ class PlatformGame():
                 self.add_bulletMonster(monster.image, monster)
             
         self.group_exitDoor.update()
+        self.group_Teleport.update()
         self.group_block.update()
         self.group_coin.update()
         self.group_hp.update()
@@ -379,6 +435,7 @@ class PlatformGame():
         self.group_bulletMonster.update()
         
         self.group_exitDoor.draw(self.screen)
+        self.group_Teleport.draw(self.screen)
         self.group_block.draw(self.screen)
         self.group_coin.draw(self.screen)
         self.group_hp.draw(self.screen)
@@ -388,7 +445,7 @@ class PlatformGame():
         self.group_lava.draw(self.screen)
         self.group_bullet.draw(self.screen)
         self.group_bulletMonster.draw(self.screen)
-        if self.on_mouse_point:
+        if self.on_mouse_point and self.on_alpha==False:
             self.draw_mouse_point()
             
         self.draw_status_msg()
\ No newline at end of file
